pub struct Application {
pub(super) settings: Settings,
pub(super) system_settings: SystemSettings,
pub(super) session_list: SessionList,
intent_handler: BoundObjectWeakRef<Object>,
last_network_state: Cell<NetworkState>,
}Fields
settings: SettingsThe application settings.
system_settings: SystemSettingsThe system settings.
session_list: SessionListThe list of logged-in sessions.
intent_handler: BoundObjectWeakRef<Object>last_network_state: Cell<NetworkState>Implementations
Sourceimpl Application
impl Application
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Application
impl Application
Sourcefn present_main_window(&self) -> Window
fn present_main_window(&self) -> Window
Get or create the main window and make sure it is visible.
Returns the main window.
Sourcefn set_up_gactions(&self)
fn set_up_gactions(&self)
Set up the application actions.
Sourcefn set_up_accels(&self)
fn set_up_accels(&self)
Sets up keyboard shortcuts for application and window actions.
Sourcefn show_about_dialog(&self)
fn show_about_dialog(&self)
Show the dialog with information about the application.
Sourcefn process_uri(&self, uri: &str)
fn process_uri(&self, uri: &str)
Process the given URI.
Sourcefn select_session_for_intent(&self, intent: SessionIntent)
fn select_session_for_intent(&self, intent: SessionIntent)
Select a session to handle the given intent as soon as possible.
Sourceasync fn ask_session_for_intent(&self, intent: SessionIntent)
async fn ask_session_for_intent(&self, intent: SessionIntent)
Ask the user to choose a session to process the given Matrix ID URI.
The session list needs to be ready.
Sourcefn process_session_intent(&self, session_id: String, intent: SessionIntent)
fn process_session_intent(&self, session_id: String, intent: SessionIntent)
Process the given intent for the given session, as soon as the session is ready.